==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/WeeklyScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.DayOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Weekly schedule.
 * @property scheduleRunDays Schedule run days.
 * @property scheduleRunTimes List of times of day this schedule has to be run.
 */
public data class WeeklyScheduleArgs(
    public val scheduleRunDays: Output<List<DayOfWeek>>? = null,
    public val scheduleRunTimes: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs =
        com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs.builder()
            .scheduleRunDays(
                scheduleRunDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .scheduleRunTimes(scheduleRunTimes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WeeklyScheduleArgs].
 */
@PulumiTagMarker
public class WeeklyScheduleArgsBuilder internal constructor() {
    private var scheduleRunDays: Output<List<DayOfWeek>>? = null

    private var scheduleRunTimes: Output<List<String>>? = null

    /**
     * @param value Schedule run days.
     */
    @JvmName("akucyhbksqmyejjv")
    public suspend fun scheduleRunDays(`value`: Output<List<DayOfWeek>>) {
        this.scheduleRunDays = value
    }

    @JvmName("apckpuiprptiblyp")
    public suspend fun scheduleRunDays(vararg values: Output<DayOfWeek>) {
        this.scheduleRunDays = Output.all(values.asList())
    }

    /**
     * @param values Schedule run days.
     */
    @JvmName("hokgyftjijkamaog")
    public suspend fun scheduleRunDays(values: List<Output<DayOfWeek>>) {
        this.scheduleRunDays = Output.all(values)
    }

    /**
     * @param value List of times of day this schedule has to be run.
     */
    @JvmName("hyylqcqqgqcyvaeh")
    public suspend fun scheduleRunTimes(`value`: Output<List<String>>) {
        this.scheduleRunTimes = value
    }

    @JvmName("ronlqshywrdqwnnw")
    public suspend fun scheduleRunTimes(vararg values: Output<String>) {
        this.scheduleRunTimes = Output.all(values.asList())
    }

    /**
     * @param values List of times of day this schedule has to be run.
     */
    @JvmName("dsugwelgyviwgexi")
    public suspend fun scheduleRunTimes(values: List<Output<String>>) {
        this.scheduleRunTimes = Output.all(values)
    }

    /**
     * @param value Schedule run days.
     */
    @JvmName("ntmaxpelrojhhuyi")
    public suspend fun scheduleRunDays(`value`: List<DayOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduleRunDays = mapped
    }

    /**
     * @param values Schedule run days.
     */
    @JvmName("mrbjcnmpiwrxtoyd")
    public suspend fun scheduleRunDays(vararg values: DayOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scheduleRunDays = mapped
    }

    /**
     * @param value List of times of day this schedule has to be run.
     */
    @JvmName("hqlmgwpktccdbxuf")
    public suspend fun scheduleRunTimes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduleRunTimes = mapped
    }

    /**
     * @param values List of times of day this schedule has to be run.
     */
    @JvmName("tcvrughaytwwnfqa")
    public suspend fun scheduleRunTimes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scheduleRunTimes = mapped
    }

    internal fun build(): WeeklyScheduleArgs = WeeklyScheduleArgs(
        scheduleRunDays = scheduleRunDays,
        scheduleRunTimes = scheduleRunTimes,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/WeeklyScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.DayOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Weekly schedule.
 * @property scheduleRunDays Schedule run days.
 * @property scheduleRunTimes List of times of day this schedule has to be run.
 */
public data class WeeklyScheduleArgs(
    public val scheduleRunDays: Output<List<DayOfWeek>>? = null,
    public val scheduleRunTimes: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs =
        com.pulumi.azurenative.workloads.inputs.WeeklyScheduleArgs.builder()
            .scheduleRunDays(
                scheduleRunDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .scheduleRunTimes(scheduleRunTimes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WeeklyScheduleArgs].
 */
@PulumiTagMarker
public class WeeklyScheduleArgsBuilder internal constructor() {
    private var scheduleRunDays: Output<List<DayOfWeek>>? = null

    private var scheduleRunTimes: Output<List<String>>? = null

    /**
     * @param value Schedule run days.
     */
    @JvmName("ipvrivqxaeqbpfkp")
    public suspend fun scheduleRunDays(`value`: Output<List<DayOfWeek>>) {
        this.scheduleRunDays = value
    }

    @JvmName("yaequhdcgicfsblf")
    public suspend fun scheduleRunDays(vararg values: Output<DayOfWeek>) {
        this.scheduleRunDays = Output.all(values.asList())
    }

    /**
     * @param values Schedule run days.
     */
    @JvmName("cxtlqpdwtcxyrjkp")
    public suspend fun scheduleRunDays(values: List<Output<DayOfWeek>>) {
        this.scheduleRunDays = Output.all(values)
    }

    /**
     * @param value List of times of day this schedule has to be run.
     */
    @JvmName("gddbhthrwpwblybf")
    public suspend fun scheduleRunTimes(`value`: Output<List<String>>) {
        this.scheduleRunTimes = value
    }

    @JvmName("qoofalrbtlkfdbts")
    public suspend fun scheduleRunTimes(vararg values: Output<String>) {
        this.scheduleRunTimes = Output.all(values.asList())
    }

    /**
     * @param values List of times of day this schedule has to be run.
     */
    @JvmName("kcwadjdugavypovf")
    public suspend fun scheduleRunTimes(values: List<Output<String>>) {
        this.scheduleRunTimes = Output.all(values)
    }

    /**
     * @param value Schedule run days.
     */
    @JvmName("vnoveaxosfseqhqu")
    public suspend fun scheduleRunDays(`value`: List<DayOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduleRunDays = mapped
    }

    /**
     * @param values Schedule run days.
     */
    @JvmName("iiipvvdoocfcmilw")
    public suspend fun scheduleRunDays(vararg values: DayOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scheduleRunDays = mapped
    }

    /**
     * @param value List of times of day this schedule has to be run.
     */
    @JvmName("oorunfjhxjjmrelb")
    public suspend fun scheduleRunTimes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduleRunTimes = mapped
    }

    /**
     * @param values List of times of day this schedule has to be run.
     */
    @JvmName("nfpplgaytoaijfcp")
    public suspend fun scheduleRunTimes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scheduleRunTimes = mapped
    }

    internal fun build(): WeeklyScheduleArgs = WeeklyScheduleArgs(
        scheduleRunDays = scheduleRunDays,
        scheduleRunTimes = scheduleRunTimes,
    )
}
